@@ -147,18 +147,15 @@ fallback_shape (PangoEngineShape *engine,
       gunichar mirrored_ch;
       PangoGlyph index;
       char buf[6];
-      const char *input;
 
       wc = g_utf8_get_char (p);
 
-      input = p;
       if (analysis->level % 2)
 	if (pango_get_mirror_char (wc, &mirrored_ch))
 	  {
 	    wc = mirrored_ch;
 	    
 	    g_unichar_to_utf8 (wc, buf);
-	    input = buf;
 	  }
 
       if (wc == 0xa0)	/* non-break-space */
@@ -344,7 +341,8 @@ basic_engine_shape (PangoEngineShape *engine,
 
   fc_font = PANGO_FC_FONT (font);
   face = pango_fc_font_lock_face (fc_font);
-  g_return_if_fail (face != NULL);
+  if (!face)
+    return;
 
   ruleset = get_ruleset (face);
   if (!ruleset)
@@ -367,17 +365,14 @@ basic_engine_shape (PangoEngineShape *engine,
       gunichar mirrored_ch;
       PangoGlyph index;
       char buf[6];
-      const char *input;
 
       wc = g_utf8_get_char (p);
-      input = p;
       if (analysis->level % 2)
 	if (pango_get_mirror_char (wc, &mirrored_ch))
 	  {
 	    wc = mirrored_ch;
 	    
 	    g_unichar_to_utf8 (wc, buf);
-	    input = buf;
 	  }
 
       if (pango_is_zero_width (wc))	/* Zero-width characters */
@@ -424,7 +419,7 @@ basic_engine_fc_class_init (PangoEngineShapeClass *class)
 }
 
 PANGO_ENGINE_SHAPE_DEFINE_TYPE (BasicEngineFc, basic_engine_fc,
-				basic_engine_fc_class_init, NULL);
+				basic_engine_fc_class_init, NULL)
 
 void 
 PANGO_MODULE_ENTRY(init) (GTypeModule *module)
