@@ -24,13 +24,10 @@
 #include <math.h>
 #include <string.h>
 
-#include "pango-impl-utils.h"
 #include "pango-types.h"
 #include "pango-font.h"
 #include "pango-fontmap.h"
-#include "pango-utils.h"
-
-static const char bad_font_warning[] = "%s called with bad font, expect ugly output";
+#include "pango-impl-utils.h"
 
 struct _PangoFontDescription
 {
@@ -360,7 +357,7 @@ pango_font_description_set_size (PangoFontDescription *desc,
  * @desc: a #PangoFontDescription
  * 
  * Gets the size field of a font description.
- * See pango_font_description_set_size().
+ * See pango_font_description_get_size().
  * 
  * Return value: the size field for the font description in points or device units.
  *   You must call pango_font_description_get_size_is_absolute()
@@ -756,24 +753,24 @@ pango_font_descriptions_free (PangoFontDescription **descs,
 typedef struct
 {
   int value;
-  const char *str;
+  const char str[16];
 } FieldMap;
 
 static const FieldMap style_map[] = {
-  { PANGO_STYLE_NORMAL, NULL },
+  { PANGO_STYLE_NORMAL, "" },
   { PANGO_STYLE_OBLIQUE, "Oblique" },
   { PANGO_STYLE_ITALIC, "Italic" }
 };
 
 static const FieldMap variant_map[] = {
-  { PANGO_VARIANT_NORMAL, NULL },
+  { PANGO_VARIANT_NORMAL, "" },
   { PANGO_VARIANT_SMALL_CAPS, "Small-Caps" }
 };
 
 static const FieldMap weight_map[] = {
   { PANGO_WEIGHT_ULTRALIGHT, "Ultra-Light" },
   { PANGO_WEIGHT_LIGHT, "Light" },
-  { PANGO_WEIGHT_NORMAL, NULL },
+  { PANGO_WEIGHT_NORMAL, "" },
   { 500, "Medium" },
   { PANGO_WEIGHT_SEMIBOLD, "Semi-Bold" },
   { PANGO_WEIGHT_BOLD, "Bold" },
@@ -786,7 +783,7 @@ static const FieldMap stretch_map[] = {
   { PANGO_STRETCH_EXTRA_CONDENSED, "Extra-Condensed" },
   { PANGO_STRETCH_CONDENSED,       "Condensed" },
   { PANGO_STRETCH_SEMI_CONDENSED,  "Semi-Condensed" },
-  { PANGO_STRETCH_NORMAL,          NULL },
+  { PANGO_STRETCH_NORMAL,          "" },
   { PANGO_STRETCH_SEMI_EXPANDED,   "Semi-Expanded" },
   { PANGO_STRETCH_EXPANDED,        "Expanded" },
   { PANGO_STRETCH_EXTRA_EXPANDED,  "Extra-Expanded" },
@@ -800,8 +797,7 @@ find_field (const FieldMap *map, int n_elements, const char *str, int len, int *
   
   for (i=0; i<n_elements; i++)
     {
-      if (map[i].str && map[i].str[0] && g_ascii_strncasecmp (map[i].str, str, len) == 0 &&
-	  map[i].str[len] == '\0')
+      if (map[i].str && g_ascii_strncasecmp (map[i].str, str, len) == 0)
 	{
 	  if (val)
 	    *val = map[i].value;
@@ -968,7 +964,7 @@ append_field (GString *str, const FieldMap *map, int n_elements, int val)
     {
       if (map[i].value == val)
 	{
-	  if (map[i].str)
+	  if (map[i].str && map[i].str[0])
 	    {
 	      if (str->len > 0 && str->str[str->len -1] != ' ')
 		g_string_append_c (str, ' ');
@@ -1175,7 +1171,7 @@ pango_font_get_glyph_extents  (PangoFont      *font,
       if (!_pango_warning_history.get_glyph_extents)
         {
 	  _pango_warning_history.get_glyph_extents = TRUE;
-	  g_warning (bad_font_warning, "pango_font_get_glyph_extents");
+	  g_warning ("pango_font_get_glyph_extents called with bad font, expect ugly output");
 	}
       if (ink_rect)
         {
@@ -1216,17 +1212,6 @@ PangoFontMetrics *
 pango_font_get_metrics (PangoFont        *font,
 			PangoLanguage    *language)
 {
-  if (G_UNLIKELY (!PANGO_IS_FONT (font)))
-    {
-      
-      if (!_pango_warning_history.get_metrics)
-        {
-	  _pango_warning_history.get_metrics = TRUE;
-	  g_warning (bad_font_warning, "pango_font_get_metrics");
-	}
-      return pango_font_metrics_new ();
-    }
-
   return PANGO_FONT_GET_CLASS (font)->get_metrics (font, language);
 }
 
@@ -1243,17 +1228,6 @@ pango_font_get_metrics (PangoFont        *font,
 PangoFontMap *
 pango_font_get_font_map (PangoFont *font)
 {
-  if (G_UNLIKELY (!PANGO_IS_FONT (font)))
-    {
-      
-      if (!_pango_warning_history.get_font_map)
-        {
-	  _pango_warning_history.get_font_map = TRUE;
-	  g_warning (bad_font_warning, "pango_font_get_font_map");
-	}
-      return NULL;
-    }
-
   if (PANGO_FONT_GET_CLASS (font)->get_font_map)
     return PANGO_FONT_GET_CLASS (font)->get_font_map (font);
   else
