@@ -30,7 +30,6 @@
 
 #include "pango-enum-types.h"
 #include "pango-modules.h"
-#include "pango-utils.h"
 #include "pango-impl-utils.h"
 
 typedef struct _PangoModule      PangoModule;
@@ -110,7 +109,7 @@ static GType pango_module_get_type (void);
  * type. The resulting map can be used to determine the engine
  * for each character.
  * 
- * Return value: the suitable #PangoMap.
+ * Return value: 
  **/
 PangoMap *
 pango_find_map (PangoLanguage *language,
@@ -248,7 +247,7 @@ pango_module_class_init (PangoModuleClass *class)
 
 static PANGO_DEFINE_TYPE (PangoModule, pango_module,
 			  pango_module_class_init, NULL,
-			  G_TYPE_TYPE_MODULE);
+			  G_TYPE_TYPE_MODULE)
 
 static PangoEngine *
 pango_engine_pair_get_engine (PangoEnginePair *pair)
