@@ -22,7 +22,7 @@
 #include <config.h>
 #include <string.h>
 
-#include <pango/pango-coverage.h>
+#include "pango-coverage.h"
 
 typedef struct _PangoBlockInfo PangoBlockInfo;
 
@@ -165,7 +165,7 @@ pango_coverage_unref (PangoCoverage *coverage)
  * 
  * Determine whether a particular index is covered by @coverage
  * 
- * Return value: the coverage level of @coverage for character @index_.
+ * Return value: 
  **/
 PangoCoverageLevel
 pango_coverage_get (PangoCoverage *coverage,
