@@ -21,8 +21,10 @@
  */
 
 #ifndef __PANGO_IMPL_UTILS_H__
+#define __PANGO_IMPL_UTILS_H__
 
 #include <glib-object.h>
+#include <pango/pango-utils.h>
 
 G_BEGIN_DECLS
 
@@ -74,18 +76,22 @@ prefix ## _get_type (void)				                   \
 
 
 
+/* Warning history.  Used to not spew some warnings more than once. */
 typedef struct _PangoWarningHistory PangoWarningHistory;
 
 struct _PangoWarningHistory {
   guint shape_font		: 1; 
   guint shape_shape_engine	: 1;
   guint get_glyph_extents	: 1;
-  guint get_metrics		: 1;
-  guint get_font_map		: 1;
 }; 
 
 extern PangoWarningHistory _pango_warning_history;
 
+
+/* String interning for static strings */
+#define I_(string) g_intern_static_string (string)
+
+
 G_END_DECLS
 
 #endif /* __PANGO_IMPL_UTILS_H__ */
