@@ -30,7 +30,7 @@
 #include "pangocairo-private.h"
 #include "pangocairo-fc.h"
 #include "pangofc-private.h"
-#include "pango-utils.h"
+#include "pango-impl-utils.h"
 
 #define PANGO_TYPE_CAIRO_FC_FONT           (pango_cairo_fc_font_get_type ())
 #define PANGO_CAIRO_FC_FONT(object)        (G_TYPE_CHECK_INSTANCE_CAST ((object), PANGO_TYPE_CAIRO_FC_FONT, PangoCairoFcFont))
@@ -207,7 +207,7 @@ cairo_font_iface_init (PangoCairoFontIface *iface)
 }
 
 G_DEFINE_TYPE_WITH_CODE (PangoCairoFcFont, pango_cairo_fc_font, PANGO_TYPE_FC_FONT,
-    { G_IMPLEMENT_INTERFACE (PANGO_TYPE_CAIRO_FONT, cairo_font_iface_init) });
+    { G_IMPLEMENT_INTERFACE (PANGO_TYPE_CAIRO_FONT, cairo_font_iface_init) })
 
 static void
 pango_cairo_fc_font_finalize (GObject *object)
@@ -645,10 +645,5 @@ _pango_cairo_fc_font_new (PangoCairoFcFontMap        *cffontmap,
 
   cffont->options = cairo_font_options_copy (_pango_cairo_context_get_merged_font_options (context));
   
-  /* fcfont's is_hinted controls metric hinting
-   */
-  PANGO_FC_FONT(cffont)->is_hinted = 
-    (cairo_font_options_get_hint_metrics(cffont->options) != CAIRO_HINT_METRICS_OFF);
-
   return PANGO_FC_FONT (cffont);
 }
