@@ -23,14 +23,14 @@
 
 #include "pangocairo.h"
 #include "pangocairo-private.h"
-#include "pango-utils.h"
+#include "pango-impl-utils.h"
 
 #if defined (HAVE_CAIRO_ATSUI)
 #  include "pangocairo-atsui.h"
-#elif defined (HAVE_CAIRO_FREETYPE)
-#  include "pangocairo-fc.h"
 #elif defined (HAVE_CAIRO_WIN32)
 #  include "pangocairo-win32.h"
+#elif defined (HAVE_CAIRO_FREETYPE)
+#  include "pangocairo-fc.h"
 #endif
 
 GType
