@@ -33,7 +33,7 @@
 
 #include "pango-engine-private.h"
 #include "pango-fontmap.h"
-#include "pango-utils.h"
+#include "pango-impl-utils.h"
 
 #undef PANGO_DISABLE_DEPRECATED
 
@@ -98,7 +98,7 @@ struct _PangoXSizeInfo
 };
 
 static const struct {
-  const gchar *text;
+  const gchar text[12];
   PangoWeight value;
 } weights_map[] = {
   { "light",     300 },
@@ -115,7 +115,7 @@ static const struct {
 };
 
 static const struct {
-  const gchar *text;
+  const gchar text[4];
   PangoStyle value;
 } styles_map[] = {
   { "r", PANGO_STYLE_NORMAL },
@@ -124,7 +124,7 @@ static const struct {
 };
 
 static const struct {
-  const gchar *text;
+  const gchar text[16];
   PangoStretch value;
 } stretches_map[] = {
   { "normal",        PANGO_STRETCH_NORMAL },
@@ -1291,7 +1291,6 @@ pango_x_make_matching_xlfd (PangoFontMap *fontmap, char *xlfd, const char *chars
       if (match_scaleable)
 	{
 	  char *prefix_end, *p;
-	  char *size_end;
 	  int n_dashes = 0;
 	  int target_size;
 	  char *prefix;
@@ -1315,8 +1314,6 @@ pango_x_make_matching_xlfd (PangoFontMap *fontmap, char *xlfd, const char *chars
 	      p++;
 	    }
 	  
-	  size_end = p - 1;
-
 	  target_size = (int)((double)size / xfontmap->resolution + 0.5);
 	  prefix = g_strndup (closest_match, prefix_end - closest_match);
 	  result  = g_strdup_printf ("%s--%d-*-*-*-*-*-%s", prefix, target_size, charset);
